ChatViewAttachment class

Constructors

ChatViewAttachment({String? url, String? type, String? caption})
ChatViewAttachment.fromJson(Map<String, dynamic> json)

Properties

caption → String?
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String?
final
url → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override