IOSChatSettings class

Annotations

Constructors

IOSChatSettings({String? title, String? sendButtonColor, String? navigationBarItemsColor, String? navigationBarColor, String? navigationBarTitleColor})

Properties

hashCode → int
The hash code for this object.
no setterinherited
final
final
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendButtonColor → String?
final
title → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited