WidgetAttachmentConfig class

Constructors

WidgetAttachmentConfig({int? maxSize, bool? isEnabled, Set<String>? allowedExtensions})
WidgetAttachmentConfig.fromJson(Map<String, dynamic> json)
factory

Properties

allowedExtensions → Set<String>?
final
hashCode → int
The hash code for this object.
no setteroverride
isEnabled → bool?
final
maxSize → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override