WidgetInfo class

Constructors

WidgetInfo({String? id, String? title, String? primaryColor, String? backgroundColor, String? primaryTextColor, bool? multiThread, bool? multiChannelConversationEnabled, bool? callsEnabled, List<String>? themeNames, WidgetAttachmentConfig? attachmentConfig})
WidgetInfo.fromJson(Map<String, dynamic> json)

Properties

attachmentConfig → WidgetAttachmentConfig?
final
backgroundColor → String?
final
callsEnabled → bool?
final
hashCode → int
The hash code for this object.
no setteroverride
id → String?
final
multiChannelConversationEnabled → bool?
final
multiThread → bool?
final
primaryColor → String?
final
primaryTextColor → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
themeNames → List<String>?
final
title → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override