AndroidSettings class

Constructors

AndroidSettings({FirebaseOptions? firebaseOptions, String? notificationIcon, bool? multipleNotifications, String? notificationAccentColor})

Properties

firebaseOptions → FirebaseOptions?
final
hashCode → int
The hash code for this object.
no setterinherited
multipleNotifications → bool?
final
notificationAccentColor → String?
final
notificationIcon → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited