Configuration class

Constructors

Configuration({required String applicationCode, String? pluginVersion, bool? inAppChatEnabled, bool? fullFeaturedInAppsEnabled, AndroidSettings? androidSettings, IOSSettings? iosSettings, PrivacySettings? privacySettings, List<NotificationCategory>? notificationCategories, bool? defaultMessageStorage, WebRTCUI? webRTCUI, InAppChatCustomization? inAppChatCustomization})

Properties

androidSettings → AndroidSettings?
final
applicationCode → String
The application code of your Application from Push Portal website
final
defaultMessageStorage → bool?
final
fullFeaturedInAppsEnabled → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
inAppChatCustomization → InAppChatCustomization?
final
inAppChatEnabled → bool?
final
iosSettings → IOSSettings?
final
notificationCategories → List<NotificationCategory>?
final
pluginVersion ↔ String?
getter/setter pair
privacySettings → PrivacySettings?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
webRTCUI → WebRTCUI?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited