IOSInAppChatCustomization class

Annotations

Constructors

IOSInAppChatCustomization({String? attachmentPreviewBarsColor, String? attachmentPreviewItemsColor, double? textContainerTopMargin, double? textContainerLeftPadding, double? textContainerCornerRadius, double? textViewTopMargin, double? placeholderHeight, double? placeholderSideMargin, double? buttonHeight, double? buttonTouchableOverlap, double? buttonRightMargin, double? utilityButtonWidth, double? utilityButtonBottomMargin, double? initialHeight, String? mainFont, String? charCountFont})

Properties

attachmentPreviewBarsColor → String?
final
attachmentPreviewItemsColor → String?
final
buttonHeight → double?
final
buttonRightMargin → double?
final
buttonTouchableOverlap → double?
final
charCountFont → String?
final
hashCode → int
The hash code for this object.
no setterinherited
initialHeight → double?
final
mainFont → String?
final
placeholderHeight → double?
final
placeholderSideMargin → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textContainerCornerRadius → double?
final
textContainerLeftPadding → double?
final
textContainerTopMargin → double?
final
textViewTopMargin → double?
final
utilityButtonBottomMargin → double?
final
utilityButtonWidth → double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited