InAppChatCustomization class

Annotations

Constructors

InAppChatCustomization({String? toolbarTitle, String? toolbarTitleColor, String? toolbarTintColor, String? toolbarBackgroundColor, String? sendButtonTintColor, String? chatBackgroundColor, String? widgetTheme, String? noConnectionAlertTextColor, String? noConnectionAlertBackgroundColor, String? chatInputPlaceholderColor, String? chatInputCursorColor, String? chatInputBackgroundColor, String? sendButtonIcon, String? attachmentButtonIcon, bool? chatInputSeparatorVisible, AndroidInAppChatCustomization? android, IOSInAppChatCustomization? ios})

Properties

android → AndroidInAppChatCustomization?
final
attachmentButtonIcon → String?
final
chatBackgroundColor → String?
final
chatInputBackgroundColor → String?
final
chatInputCursorColor → String?
final
chatInputPlaceholderColor → String?
final
chatInputSeparatorVisible → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
ios → IOSInAppChatCustomization?
final
noConnectionAlertBackgroundColor → String?
final
noConnectionAlertTextColor → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendButtonIcon → String?
final
sendButtonTintColor → String?
final
toolbarBackgroundColor → String?
final
toolbarTintColor → String?
final
toolbarTitle → String?
final
toolbarTitleColor → String?
final
widgetTheme → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited