NotificationAction class

Constructors

NotificationAction({String? identifier, String? title, bool? foreground, bool? authenticationRequired, bool? moRequired, bool? destructive, String? icon, String? textInputActionButtonTitle, String? textInputPlaceholder})

Properties

authenticationRequired → bool?
final
destructive → bool?
final
foreground → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
icon → String?
final
identifier → String?
final
moRequired → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textInputActionButtonTitle → String?
final
textInputPlaceholder → String?
final
title → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited