AndroidSettings class

Android specific settings.

Constructors

AndroidSettings({FirebaseOptions? firebaseOptions, String? notificationIcon, String? notificationChannelId, String? notificationChannelName, String? notificationSound, bool? multipleNotifications, String? notificationAccentColor})
Default constructor with all params.

Properties

firebaseOptions → FirebaseOptions?
Helper class to initialize Firebase configuration using key/values.
final
hashCode → int
The hash code for this object.
no setterinherited
multipleNotifications → bool?
Should multiple notifications in status bar be shown. By default only the latest notification is shown.
final
notificationAccentColor → String?
Accent color for notification.
final
notificationChannelId → String?
Custom notification channel ID.
final
notificationChannelName → String?
Custom notification channel name.
final
notificationIcon → String?
A resource name for a status bar icon (without extension), located in '/platforms/android/app/src/main/res/mipmap'
final
notificationSound → String?
A resource name for the custom sound name (without extension), located in '/android/app/src/main/res/raw'
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Mapping AndroidSettings to json.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited