ChatCustomization class

Constructors

ChatCustomization({String? chatStatusBarBackgroundColor, String? chatStatusBarIconsColorMode, ToolbarCustomization? chatToolbar, ToolbarCustomization? attachmentPreviewToolbar, String? attachmentPreviewToolbarSaveMenuItemIcon, String? attachmentPreviewToolbarMenuItemsIconTint, String? networkErrorText, String? networkErrorTextColor, String? networkErrorTextAppearance, String? networkErrorLabelBackgroundColor, String? networkErrorIcon, String? networkErrorIconTint, String? chatBannerErrorTextColor, String? chatBannerErrorTextAppearance, String? chatBannerErrorBackgroundColor, String? chatBannerErrorIcon, String? chatBannerErrorIconTint, String? chatFullScreenErrorTitleText, String? chatFullScreenErrorTitleTextColor, String? chatFullScreenErrorTitleTextAppearance, String? chatFullScreenErrorDescriptionText, String? chatFullScreenErrorDescriptionTextColor, String? chatFullScreenErrorDescriptionTextAppearance, String? chatFullScreenErrorBackgroundColor, String? chatFullScreenErrorIcon, String? chatFullScreenErrorIconTint, String? chatFullScreenErrorRefreshButtonText, String? chatFullScreenErrorRefreshButtonTextColor, bool? chatFullScreenErrorRefreshButtonVisible, String? chatBackgroundColor, String? chatProgressBarColor, String? chatInputTextAppearance, String? chatInputTextColor, String? chatInputBackgroundColor, String? chatInputHintText, String? chatInputHintTextColor, String? chatInputAttachmentIcon, String? chatInputAttachmentIconTint, String? chatInputAttachmentDisabledIconTint, String? chatInputAttachmentBackgroundDrawable, String? chatInputAttachmentBackgroundColor, String? chatInputSendIcon, String? chatInputSendIconTint, String? chatInputSendDisabledIconTint, String? chatInputSendBackgroundDrawable, String? chatInputSendBackgroundColor, String? chatInputSeparatorLineColor, bool? chatInputSeparatorLineVisible, String? chatInputCursorColor, String? chatInputCharCounterTextAppearance, String? chatInputCharCounterDefaultColor, String? chatInputCharCounterAlertColor, bool? shouldHandleKeyboardAppearance})

Properties

attachmentPreviewToolbar → ToolbarCustomization?
final
attachmentPreviewToolbarMenuItemsIconTint → String?
final
attachmentPreviewToolbarSaveMenuItemIcon → String?
final
chatBackgroundColor → String?
final
chatBannerErrorBackgroundColor → String?
final
chatBannerErrorIcon → String?
final
chatBannerErrorIconTint → String?
final
chatBannerErrorTextAppearance → String?
final
chatBannerErrorTextColor → String?
final
chatFullScreenErrorBackgroundColor → String?
final
chatFullScreenErrorDescriptionText → String?
final
chatFullScreenErrorDescriptionTextAppearance → String?
final
chatFullScreenErrorDescriptionTextColor → String?
final
chatFullScreenErrorIcon → String?
final
chatFullScreenErrorIconTint → String?
final
chatFullScreenErrorRefreshButtonText → String?
final
chatFullScreenErrorRefreshButtonTextColor → String?
final
chatFullScreenErrorRefreshButtonVisible → bool?
final
chatFullScreenErrorTitleText → String?
final
chatFullScreenErrorTitleTextAppearance → String?
final
chatFullScreenErrorTitleTextColor → String?
final
chatInputAttachmentBackgroundColor → String?
final
chatInputAttachmentBackgroundDrawable → String?
final
chatInputAttachmentDisabledIconTint → String?
final
chatInputAttachmentIcon → String?
final
chatInputAttachmentIconTint → String?
final
chatInputBackgroundColor → String?
final
chatInputCharCounterAlertColor → String?
final
chatInputCharCounterDefaultColor → String?
final
chatInputCharCounterTextAppearance → String?
final
chatInputCursorColor → String?
final
chatInputHintText → String?
final
chatInputHintTextColor → String?
final
chatInputSendBackgroundColor → String?
final
chatInputSendBackgroundDrawable → String?
final
chatInputSendDisabledIconTint → String?
final
chatInputSendIcon → String?
final
chatInputSendIconTint → String?
final
chatInputSeparatorLineColor → String?
final
chatInputSeparatorLineVisible → bool?
final
chatInputTextAppearance → String?
final
chatInputTextColor → String?
final
chatProgressBarColor → String?
final
chatStatusBarBackgroundColor → String?
final
chatStatusBarIconsColorMode → String?
final
chatToolbar → ToolbarCustomization?
final
hashCode → int
The hash code for this object.
no setterinherited
networkErrorIcon → String?
final
networkErrorIconTint → String?
final
networkErrorLabelBackgroundColor → String?
final
networkErrorText → String?
final
networkErrorTextAppearance → String?
final
networkErrorTextColor → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shouldHandleKeyboardAppearance → bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited