FirebaseOptions class

Helper class to initialize Firebase configuration using key/values. Recommended to use Firebase configuration file instead, docs.

Constructors

FirebaseOptions({required String apiKey, required String applicationId, required String projectId, String? databaseUrl, String? gaTrackingId, String? gcmSenderId, String? storageBucket})

Properties

apiKey → String
final
applicationId → String
final
databaseUrl → String?
final
gaTrackingId → String?
final
gcmSenderId → String?
final
hashCode → int
The hash code for this object.
no setterinherited
projectId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storageBucket → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited