NotificationAction class

Helper class for setting interactive notifications' action.

Constructors

NotificationAction({String? identifier, String? title, bool? foreground, bool? authenticationRequired, bool? moRequired, bool? destructive, String? icon, String? textInputActionButtonTitle, String? textInputPlaceholder})
Default constructor with all parameters.

Properties

authenticationRequired → bool?
iOS only: require device to be unlocked before performing.
final
destructive → bool?
iOS only: should message be marked as destructive.
final
foreground → bool?
To bring the app to foreground or leave it in background state.
final
hashCode → int
The hash code for this object.
no setterinherited
icon → String?
Android only: resource name for the special action icon.
final
identifier → String?
Unique identifier of the notification category.
final
moRequired → bool?
Should MO message sending be triggered.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textInputActionButtonTitle → String?
iOS only: custom label for sending button.
final
textInputPlaceholder → String?
Custom input field placeholder.
final
title → String?
An action title, represents a notification action button label.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Mapping NotificationAction to json.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited