ToolbarCustomization class

Constructors

ToolbarCustomization({String? titleTextAppearance, String? titleTextColor, String? titleText, bool? titleCentered, String? backgroundColor, String? navigationIcon, String? navigationIconTint, String? subtitleTextAppearance, String? subtitleTextColor, String? subtitleText, bool? subtitleCentered})

Properties

backgroundColor → String?
final
hashCode → int
The hash code for this object.
no setterinherited
final
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtitleCentered → bool?
final
subtitleText → String?
final
subtitleTextAppearance → String?
final
subtitleTextColor → String?
final
titleCentered → bool?
final
titleText → String?
final
titleTextAppearance → String?
final
titleTextColor → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited