Installation class

Mobile Messaging Installation class.

Constructors

Installation({String? pushRegistrationId, PushServiceType? pushServiceType, String? pushServiceToken, bool? isPrimaryDevice, bool? isPushRegistrationEnabled, bool? notificationsEnabled, String? sdkVersion, String? appVersion, OS? os, String? osVersion, String? deviceManufacturer, String? deviceModel, bool? deviceSecure, String? language, String? deviceTimezoneOffset, String? applicationUserId, String? deviceName, Map<String, dynamic>? customAttributes})
Default constructor with all params. Use InfobipMobilemessaging.fetchInstallation or InfobipMobilemessaging.getInstallation to get Installation.
Installation.fromJson(Map<String, dynamic> json)
Parsing Installation from json.

Properties

applicationUserId → String?
iOS specific internal setting.
final
appVersion → String?
Application version.
final
customAttributes ↔ Map<String, dynamic>?
Installation-level custom attributes.
getter/setter pair
deviceManufacturer → String?
Device manufacturer name.
final
deviceModel → String?
Model of the device.
final
deviceName → String?
Name of the device.
final
deviceSecure → bool?
Flag if device screen lock is enabled.
final
deviceTimezoneOffset → String?
Timezone from system settings, difference from UTC.
final
hashCode → int
The hash code for this object.
no setteroverride
isPrimaryDevice ↔ bool?
Flag to indicate if installation is primary. Can be used to distinguish main device of user, and to target only it to deliver sensitive messages.
getter/setter pair
isPushRegistrationEnabled ↔ bool?
Flag if installation opted-in for receiving push notifications on OS level.
getter/setter pair
language → String?
Device language.
final
notificationsEnabled ↔ bool?
Flag if installation opted-in for receiving push notifications on app level.
getter/setter pair
os → OS?
OS value.
final
osVersion → String?
OS version.
final
pushRegistrationId → String?
Push registration ID of the installation issued by Infobip platform.
final
pushServiceToken → String?
Token issued by respective push service.
final
pushServiceType → PushServiceType?
Type of the push service.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sdkVersion → String?
Mobile Messaging SDK version.
final

Methods

getPushRegistrationId() → String?
Returns pushRegistrationId for installation.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Mapping Installation to json.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override