InstallationPrimary class

Helper class for setting Installation as a primary.

Constructors

InstallationPrimary(String pushRegistrationId, bool primary)
Default constructor with all params.

Properties

hashCode → int
The hash code for this object.
no setterinherited
primary → bool
Should be set to true.
final
pushRegistrationId → String
Push registration ID of the device to set as primary.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Mapping InstallationPrimary to json.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited