Message class

MobileMessaging Message class.

Constructors

Message({required String messageId, String? title, String? body, String? sound, bool? silent, Map<String, dynamic>? customPayload, String? internalData, num? receivedTimestamp, num? seenDate, String? contentUrl, bool? seen, Map<String, dynamic>? originalPayload, bool? vibrate, String? icon, String? category, String? browserUrl, String? deeplink, String? webViewUrl, String? inAppOpenTitle, String? inAppDismissTitle, bool? chat})
Default constructor with all params.
Message.fromJson(Map<String, dynamic> json)
Parsing Message from json.

Properties

body → String?
Optional message body.
final
browserUrl → String?
Optional url to open in browser.
final
category → String?
Android only: category of the message.
final
chat → bool?
Optional flag is message for LiveChat.
final
contentUrl → String?
Link to the message content.
final
customPayload → Map<String, dynamic>?
Optional custom payload of the message.
final
Optional deeplink.
final
hashCode → int
The hash code for this object.
no setteroverride
icon → String?
Android only: icon for the message.
final
inAppDismissTitle → String?
Optional in-app message: title for cancel/dismiss action.
final
inAppOpenTitle → String?
Optional in-app message: title for open action.
final
internalData → String?
Internal data.
final
messageId → String
Id of the Message.
final
originalPayload → Map<String, dynamic>?
iOS only: original APNS payload.
final
receivedTimestamp → num?
Optional message received timestamp in millis from Epoch.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seen → bool?
Optional flag if message was marked as seen.
final
seenDate → num?
Optional message seen timestamp in millis from Epoch.
final
silent → bool?
Optional: silent message flag.
final
sound → String?
Optional message sound.
final
title → String?
Optional message title.
final
vibrate → bool?
Android only: vibrate for the message.
final
webViewUrl → String?
Optional url to open in webView.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override