NativeLog class

MobileMessaging NativeLog class.

Constructors

NativeLog({required String message})
Default constructor with all params.
NativeLog.fromJson(Map<String, dynamic> json)
Parsing Message from json.

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
The content of the log message.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited