PersonalizeContext class

PersonalizeContext class for personalization with parameters.

Constructors

PersonalizeContext({UserIdentity? userIdentity, UserAttributes? userAttributes, bool? forceDepersonalize, bool? keepAsLead, bool? setDeviceAsPrimary})
Default constructor with all params.

Properties

forceDepersonalize → bool?
Flag to depersonalize the current installation from previous person profile. Recommended to set as true unless special profiling logic introduced. If set to false and installation is already personalized - will produce an error.
final
hashCode → int
The hash code for this object.
no setteroverride
keepAsLead → bool?
Flag to perform personalization without promoting profile to Type.CUSTOMER and keep Type.LEAD.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setDeviceAsPrimary → bool?
Flag to mark this installation as primary for the personalized user.
final
userAttributes → UserAttributes?
UserAttributes class.
final
userIdentity → UserIdentity?
UserIdentity class.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Mapping PersonalizeContext to json.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override