UserIdentity class

UserIdentity class used for personalization.

Constructors

UserIdentity({List<String>? phones, List<String>? emails, String? externalUserId})
Default constructor with all params.

Properties

emails → List<String>?
List of emails in rfc2822 format, i.e. user@infobip.com.
final
externalUserId → String?
ExternalUserId.
final
hashCode → int
The hash code for this object.
no setteroverride
phones → List<String>?
List of phones in E.164 format, i.e. 38516419710.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Mapping UserIdentity to json.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override