Installation class

Constructors

Installation({String? pushRegistrationId, PushServiceType? pushServiceType, String? pushServiceToken, bool? isPrimaryDevice, bool? isPushRegistrationEnabled, bool? notificationsEnabled, bool? geoEnabled, String? sdkVersion, String? appVersion, OS? os, String? osVersion, String? deviceManufacturer, String? deviceModel, bool? deviceSecure, String? language, String? deviceTimezoneOffset, String? applicationUserId, String? deviceName, Map<String, dynamic>? customAttributes})
Installation.fromJson(Map<String, dynamic> json)

Properties

applicationUserId → String?
final
appVersion → String?
final
customAttributes ↔ Map<String, dynamic>?
getter/setter pair
deviceManufacturer → String?
final
deviceModel → String?
final
deviceName → String?
final
deviceSecure → bool?
final
deviceTimezoneOffset → String?
final
geoEnabled ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
isPrimaryDevice ↔ bool?
getter/setter pair
isPushRegistrationEnabled ↔ bool?
getter/setter pair
language → String?
final
notificationsEnabled ↔ bool?
getter/setter pair
os → OS?
final
osVersion → String?
final
pushRegistrationId → String?
final
pushServiceToken → String?
final
pushServiceType → PushServiceType?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sdkVersion → String?
final

Methods

getPushRegistrationId() → String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromString(String? str) → OS?
resolvePushServiceType(String? pst) → PushServiceType?