Message class

Constructors

Message({required String messageId, String? title, String? body, String? sound, bool? silent, Map<String, dynamic>? customPayload, String? internalData, num? receivedTimestamp, num? seenDate, String? contentUrl, bool? seen, bool? geo, Map<String, dynamic>? originalPayload, bool? vibrate, String? icon, String? category, String? browserUrl, String? deeplink, String? webViewUrl, String? inAppOpenTitle, String? inAppDismissTitle, bool? chat})
Message.fromJson(Map<String, dynamic> json)

Properties

body → String?
final
browserUrl → String?
final
category → String?
final
chat → bool?
final
contentUrl → String?
final
customPayload → Map<String, dynamic>?
final
final
geo → bool?
final
hashCode → int
The hash code for this object.
no setteroverride
icon → String?
final
inAppDismissTitle → String?
final
inAppOpenTitle → String?
final
internalData → String?
final
messageId → String
final
originalPayload → Map<String, dynamic>?
final
receivedTimestamp → num?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seen → bool?
final
seenDate → num?
final
silent → bool?
final
sound → String?
final
title → String?
final
vibrate → bool?
final
webViewUrl → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override