DefaultMessageStorage class

Default message storage implementation.

Inheritance

Constructors

DefaultMessageStorage(MethodChannel _channel)
Default constructor.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String messageId) → Future<void>
Deletes message with given messageId.
override
deleteAll() → Future<void>
Deletes all messages.
override
find(String messageId) → Future<Message?>
Finds a Message by its messageId.
override
findAll() → Future<List<Message>?>
Finds all stored messages.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited