MessageStorage class abstract

Abstract message storage class.

Implementers

Constructors

MessageStorage()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String messageId) → Future<void>
Deletes message with given messageId.
deleteAll() → Future<void>
Deletes all messages.
find(String messageId) → Future<Message?>
Finds a Message by its messageId.
findAll() → Future<List<Message>?>
Finds all stored messages.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited