PersonalizeContext class

Constructors

PersonalizeContext({UserIdentity? userIdentity, Map<String, dynamic>? userAttributes, bool? forceDepersonalize, bool? keepAsLead})

Properties

forceDepersonalize → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
keepAsLead → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userAttributes → Map<String, dynamic>?
final
userIdentity → UserIdentity?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited