UserIdentity class

Constructors

UserIdentity({List<String>? phones, List<String>? emails, String? externalUserId})

Properties

emails → List<String>?
final
externalUserId → String?
final
hashCode → int
The hash code for this object.
no setterinherited
phones → List<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited