UserData class

Constructors

UserData({String? externalUserId, String? firstName, String? lastName, String? middleName, Gender? gender, String? birthday, List<String>? phones, List<String>? emails, List<String>? tags, Map<String, dynamic>? customAttributes})
UserData.fromJson(Map<String, dynamic> json)

Properties

birthday ↔ String?
getter/setter pair
customAttributes ↔ Map<String, dynamic>?
getter/setter pair
emails ↔ List<String>?
getter/setter pair
externalUserId ↔ String?
getter/setter pair
firstName ↔ String?
getter/setter pair
gender ↔ Gender?
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
lastName ↔ String?
getter/setter pair
middleName ↔ String?
getter/setter pair
phones ↔ List<String>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags ↔ List<String>?
getter/setter pair
type ↔ Type?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

resolveGender(String? str) → Gender?
resolveLists(List? str) → List<String>?
resolveType(String? str) → Type?